@@ -30,10 +30,6 @@
 
 #include "guestfs_protocol.h"
 
-#ifndef O_CLOEXEC
-#define O_CLOEXEC 0
-#endif
-
 /*-- in guestfsd.c --*/
 extern int verbose;
 
@@ -82,6 +78,13 @@ extern void free_stringslen (char **argv, size_t len);
 extern void sort_device_names (char **argv, size_t len);
 extern int compare_device_names (const char *a, const char *b);
 
+/* Concatenate strings, optionally with a separator string between
+ * each.  On error, these return NULL but do NOT call reply_with_* nor
+ * free anything.
+ */
+extern char *concat_strings (char *const *argv);
+extern char *join_strings (const char *separator, char *const *argv);
+
 extern char **split_lines (char *str);
 
 #define command(out,err,name,...) commandf((out),(err),0,(name),__VA_ARGS__)
@@ -112,6 +115,8 @@ extern int prog_exists (const char *prog);
 
 extern void udev_settle (void);
 
+extern int random_name (char *template);
+
 /* This just stops gcc from giving a warning about our custom printf
  * formatters %Q and %R.  See guestfs(3)/EXTENDING LIBGUESTFS for more
  * info about these.
