@@ -267,6 +267,17 @@ main (int argc, char *argv[])
     exit (EXIT_FAILURE);
   }
 
+  /* Wait for udev devices to be created.  If you start libguestfs,
+   * especially with disks that contain complex (eg. mdadm) data
+   * already, then it is possible for the 'mdadm' and LVM commands
+   * that the init script runs to have not completed by the time the
+   * daemon starts executing library commands.  (This is very rare and
+   * hard to test however, but we have seen it in 'brew').  Run
+   * udev_settle, but do it as late as possible to minimize the chance
+   * that we'll have to do any waiting here.
+   */
+  udev_settle ();
+
   /* Send the magic length message which indicates that
    * userspace is up inside the guest.
    */
@@ -556,6 +567,14 @@ compare_device_names (const char *a, const char *b)
   a += a_devlen;
   b += a_devlen;
 
+  /* If no partition numbers, bail -- the devices are the same.  This
+   * can happen in one peculiar case: where you have a mix of devices
+   * with different interfaces (eg. /dev/sda and /dev/vda).
+   * (RHBZ#858128).
+   */
+  if (!*a && !*b)
+    return 0;
+
   r = sscanf (a, "%d", &a_partnum);
   assert (r == 1);
   r = sscanf (b, "%d", &b_partnum);
@@ -578,6 +597,47 @@ sort_device_names (char **argv, size_t len)
   qsort (argv, len, sizeof (char *), compare_device_names_vp);
 }
 
+char *
+concat_strings (char *const *argv)
+{
+  return join_strings ("", argv);
+}
+
+char *
+join_strings (const char *separator, char *const *argv)
+{
+  size_t i, len, seplen, rlen;
+  char *r;
+
+  seplen = strlen (separator);
+
+  len = 0;
+  for (i = 0; argv[i] != NULL; ++i) {
+    if (i > 0)
+      len += seplen;
+    len += strlen (argv[i]);
+  }
+  len++; /* for final \0 */
+
+  r = malloc (len);
+  if (r == NULL)
+    return NULL;
+
+  rlen = 0;
+  for (i = 0; argv[i] != NULL; ++i) {
+    if (i > 0) {
+      memcpy (&r[rlen], separator, seplen);
+      rlen += seplen;
+    }
+    len = strlen (argv[i]);
+    memcpy (&r[rlen], argv[i], len);
+    rlen += len;
+  }
+  r[rlen] = '\0';
+
+  return r;
+}
+
 /* Easy ways to run external commands.  For full documentation, see
  * 'commandrvf' below.
  */
@@ -1190,6 +1250,52 @@ prog_exists (const char *prog)
   return 0;
 }
 
+/* Pass a template such as "/sysroot/XXXXXXXX.XXX".  This updates the
+ * template to contain a randomly named file.  Any 'X' characters
+ * after the final '/' are replaced with random characters.
+ *
+ * Notes: You should probably use an 8.3 path, so it's compatible with
+ * all filesystems including basic FAT.  Also this only substitutes
+ * lowercase ASCII letters and numbers, again for compatibility with
+ * lowest common denominator filesystems.
+ *
+ * This doesn't create a file or check whether or not the file exists
+ * (it would be extremely unlikely to exist as long as the RNG is
+ * working).
+ *
+ * If there is an error, -1 is returned.
+ */
+int
+random_name (char *template)
+{
+  int fd;
+  unsigned char c;
+  char *p;
+
+  fd = open ("/dev/urandom", O_RDONLY|O_CLOEXEC);
+  if (fd == -1)
+    return -1;
+
+  p = strrchr (template, '/');
+  if (p == NULL)
+    abort ();                   /* internal error - bad template */
+
+  while (*p) {
+    if (*p == 'X') {
+      if (read (fd, &c, 1) != 1) {
+        close (fd);
+        return -1;
+      }
+      *p = "0123456789abcdefghijklmnopqrstuvwxyz"[c % 36];
+    }
+
+    p++;
+  }
+
+  close (fd);
+  return 0;
+}
+
 /* LVM and other commands aren't synchronous, especially when udev is
  * involved.  eg. You can create or remove some device, but the /dev
  * device node won't appear until some time later.  This means that
