@@ -34,7 +34,7 @@ do_hexdump (const char *path)
   char *out, *err;
 
   CHROOT_IN;
-  fd = open (path, O_RDONLY);
+  fd = open (path, O_RDONLY|O_CLOEXEC);
   CHROOT_OUT;
 
   if (fd == -1) {
