@@ -49,7 +49,7 @@ static int write_pid_file (const char *pid_file, pid_t pid);
  * Copyright (C) 2001-2007  Miklos Szeredi <miklos@szeredi.hu>
  * This [function] can be distributed under the terms of the GNU LGPLv2.
  */
-static int
+static void
 fuse_opt_add_opt_escaped (char **opts, const char *opt)
 {
   unsigned oldlen = *opts ? strlen(*opts) : 0;
@@ -105,7 +105,7 @@ usage (int status)
              "%s lets you mount a virtual machine filesystem\n"
              "Copyright (C) 2009-2012 Red Hat Inc.\n"
              "Usage:\n"
-             "  %s [--options] [-- [--FUSE-options]] mountpoint\n"
+             "  %s [--options] mountpoint\n"
              "Options:\n"
              "  -a|--add image       Add image\n"
              "  -c|--connect uri     Specify libvirt URI for -d option\n"
