@@ -72,7 +72,7 @@ let generate_fish_cmds () =
   pr "#include \"fish.h\"\n";
   pr "#include \"fish-cmds.h\"\n";
   pr "#include \"options.h\"\n";
-  pr "#include \"cmds_gperf.h\"\n";
+  pr "#include \"cmds-gperf.h\"\n";
   pr "\n";
   pr "/* Valid suffixes allowed for numbers.  See Gnulib xstrtol function. */\n";
   pr "static const char *xstrtol_suffixes = \"0kKMGTPEZY\";\n";
@@ -148,7 +148,7 @@ Guestfish will prompt for these separately."
 
       let warnings =
         warnings ^
-          match deprecation_notice flags with
+          match deprecation_notice ~replace_underscores:true flags with
           | None -> ""
           | Some txt -> "\n\n" ^ txt in
 
@@ -697,7 +697,7 @@ and generate_fish_cmds_gperf () =
 #include <stdlib.h>
 #include <string.h>
 
-#include \"cmds_gperf.h\"
+#include \"cmds-gperf.h\"
 
 ";
 
@@ -897,7 +897,7 @@ Guestfish will prompt for these separately.\n\n";
       if List.mem ProtocolLimitWarning flags then
         pr "%s\n\n" protocol_limit_warning;
 
-      match deprecation_notice flags with
+      match deprecation_notice ~replace_underscores:true flags with
       | None -> ()
       | Some txt -> pr "%s\n\n" txt
   ) all_functions_sorted
