@@ -149,7 +149,7 @@ public class GuestFS {
             pr "      _optobj = optargs.get (\"%s\");\n" n;
             pr "    if (_optobj != null) {\n";
             pr "      %s = ((%s) _optobj)%s;\n" n boxed_t convert;
-            pr "      _optargs_bitmask |= %Ld;\n"
+            pr "      _optargs_bitmask |= %LdL;\n"
               (Int64.shift_left Int64.one i);
             pr "    }\n";
         ) optargs
@@ -176,6 +176,29 @@ public class GuestFS {
       );
       pr "  }\n";
       pr "\n";
+
+      (* Generate an overloaded method that has no optargs argument,
+       * and make it call the method above with 'null' for the last
+       * arg.
+       *)
+      if optargs <> [] then (
+        pr "  ";
+        generate_java_prototype ~public:true ~semicolon:false
+          name (ret, args, []);
+        pr "\n";
+        pr "  {\n";
+        (match ret with
+        | RErr -> pr "    "
+        | _ ->    pr "    return "
+        );
+        pr "%s (" name;
+        List.iter (fun arg -> pr "%s, " (name_of_argt arg)) args;
+        pr "null);\n";
+        pr "  }\n";
+        pr "\n"
+      );
+
+      (* Prototype for the native method. *)
       pr "  ";
       generate_java_prototype ~privat:true ~native:true name style;
       pr "\n";
