@@ -37,15 +37,17 @@ let rec generate_perl_xs () =
   pr "\
 #include <config.h>
 
+#include <stdio.h>
+#include <stdlib.h>
+#include <inttypes.h>
+
 #include \"EXTERN.h\"
 #include \"perl.h\"
 #include \"XSUB.h\"
 
 #include <guestfs.h>
 
-#ifndef PRId64
-#define PRId64 \"lld\"
-#endif
+#define STREQ(a,b) (strcmp((a),(b)) == 0)
 
 static SV *
 my_newSVll(long long val) {
@@ -59,10 +61,6 @@ my_newSVll(long long val) {
 #endif
 }
 
-#ifndef PRIu64
-#define PRIu64 \"llu\"
-#endif
-
 static SV *
 my_newSVull(unsigned long long val) {
 #ifdef USE_64_BIT_ALL
@@ -75,6 +73,28 @@ my_newSVull(unsigned long long val) {
 #endif
 }
 
+/* Convert a 64 bit int on input.  To cope with the case of having
+ * a 32 bit Perl interpreter, we allow the user to pass a string
+ * here which is scanned as a 64 bit integer.
+ */
+static int64_t
+my_SvIV64 (SV *sv)
+{
+#ifdef USE_64_BIT_ALL
+  return SvIV (sv);
+#else
+  if (SvTYPE (sv) == SVt_PV) {
+    const char *str = SvPV_nolen (sv);
+    int64_t r;
+
+    sscanf (str, \"%%\" SCNi64, &r);
+    return r;
+  }
+  else
+    return SvIV (sv);
+#endif
+}
+
 /* http://www.perlmonks.org/?node_id=680842 */
 static char **
 XS_unpack_charPtrPtr (SV *arg) {
@@ -416,12 +436,12 @@ user_cancel (g)
           fun argt ->
             let n = name_of_optargt argt in
             let uc_n = String.uppercase n in
-            pr "if (strcmp (this_arg, \"%s\") == 0) {\n" n;
+            pr "if (STREQ (this_arg, \"%s\")) {\n" n;
             pr "          optargs_s.%s = " n;
             (match argt with
              | OBool _
-             | OInt _
-             | OInt64 _ -> pr "SvIV (ST (items_i+1))"
+             | OInt _ -> pr "SvIV (ST (items_i+1))"
+             | OInt64 _ -> pr "my_SvIV64 (ST (items_i+1))"
              | OString _ -> pr "SvPV_nolen (ST (items_i+1))"
             );
             pr ";\n";
@@ -610,12 +630,13 @@ Sys::Guestfs - Perl bindings for libguestfs
 
  use Sys::Guestfs;
 
- my $h = Sys::Guestfs->new ();
- $h->add_drive_opts ('guest.img', format => 'raw');
- $h->launch ();
- $h->mount_options ('', '/dev/sda1', '/');
- $h->touch ('/hello');
- $h->sync ();
+ my $g = Sys::Guestfs->new ();
+ $g->add_drive_opts ('guest.img', format => 'raw');
+ $g->launch ();
+ $g->mount_options ('', '/dev/sda1', '/');
+ $g->touch ('/hello');
+ $g->shutdown ();
+ $g->close ();
 
 =head1 DESCRIPTION
 
@@ -675,7 +696,7 @@ XSLoader::load ('Sys::Guestfs');
 
   (* Methods. *)
   pr "\
-=item $h = Sys::Guestfs->new ();
+=item $g = Sys::Guestfs->new ();
 
 Create a new guestfs handle.
 
@@ -691,7 +712,7 @@ sub new {
   return $self;
 }
 
-=item $h->close ();
+=item $g->close ();
 
 Explicitly close the guestfs handle.
 
@@ -721,7 +742,7 @@ when the final reference is cleaned up is OK).
   ) events;
 
   pr "\
-=item $event_handle = $h->set_event_callback (\\&cb, $event_bitmask);
+=item $event_handle = $g->set_event_callback (\\&cb, $event_bitmask);
 
 Register C<cb> as a callback function for all of the events
 in C<$event_bitmask> (one or more C<$Sys::Guestfs::EVENT_*> flags
@@ -759,15 +780,15 @@ You should carefully read the documentation for
 L<guestfs(3)/guestfs_set_event_callback> before using
 this function.
 
-=item $h->delete_event_callback ($event_handle);
+=item $g->delete_event_callback ($event_handle);
 
 This removes the callback which was previously registered using
 C<set_event_callback>.
 
-=item $errnum = $h->last_errno ();
+=item $errnum = $g->last_errno ();
 
 This returns the last error number (errno) that happened on the
-handle C<$h>.
+handle C<$g>.
 
 If successful, an errno integer not equal to zero is returned.
 
@@ -779,12 +800,12 @@ You can use the standard Perl module L<Errno(3)> to compare
 the numeric error returned from this call with symbolic
 errnos:
 
- $h->mkdir (\"/foo\");
- if ($h->last_errno() == Errno::EEXIST()) {
+ $g->mkdir (\"/foo\");
+ if ($g->last_errno() == Errno::EEXIST()) {
    # mkdir failed because the directory exists already.
  }
 
-=item $h->user_cancel ();
+=item $g->user_cancel ();
 
 Cancel current transfer.  This is safe to call from Perl signal
 handlers and threads.
@@ -799,7 +820,7 @@ handlers and threads.
   List.iter (
     fun (name, style, _, flags, _, _, longdesc) ->
       if not (List.mem NotInDocs flags) then (
-        let longdesc = replace_str longdesc "C<guestfs_" "C<$h-E<gt>" in
+        let longdesc = replace_str longdesc "C<guestfs_" "C<$g-E<gt>" in
         pr "=item ";
         generate_perl_prototype name style;
         pr "\n\n";
@@ -895,7 +916,7 @@ class, use the ordinary Perl UNIVERSAL method C<can(METHOD)>
 
  use Sys::Guestfs;
  if (defined (Sys::Guestfs->can (\"set_verbose\"))) {
-   print \"\\$h->set_verbose is available\\n\";
+   print \"\\$g->set_verbose is available\\n\";
  }
 
 Perl does not offer a way to list the arguments of a method, and
@@ -929,7 +950,7 @@ To test if particular features are supported by the current
 build, use the L</available> method like the example below.  Note
 that the appliance must be launched first.
 
- $h->available ( [\"augeas\"] );
+ $g->available ( [\"augeas\"] );
 
 Since the L</available> method croaks if the feature is not supported,
 you might also want to wrap this in an eval and return a boolean.
@@ -990,7 +1011,7 @@ and generate_perl_prototype name (ret, args, optargs) =
    | RStringList n
    | RStructList (n,_) -> pr "@%s = " n
   );
-  pr "$h->%s (" name;
+  pr "$g->%s (" name;
   let comma = ref false in
   List.iter (
     fun arg ->
