@@ -15,10 +15,6 @@ f.close ()
 # Set the trace flag so that we can see each libguestfs call.
 g.set_trace (1)
 
-# Set the autosync flag so that the disk will be synchronized
-# automatically when the libguestfs handle is closed.
-g.set_autosync (1)
-
 # Attach the disk image to libguestfs.
 g.add_drive_opts (output, format = "raw", readonly = 0)
 
@@ -55,7 +51,12 @@ g.mkdir ("/foo")
 # the disk image.
 g.upload ("/etc/resolv.conf", "/foo/resolv.conf")
 
-# Because 'autosync' was set (above) we can just close the handle
-# and the disk contents will be synchronized.  You can also do
-# this manually by calling g.umount_all and g.sync.
+# Because we wrote to the disk and we want to detect write
+# errors, call g.shutdown.  You don't need to do this:
+# g.close will do it implicitly.
+g.shutdown ()
+
+# Note also that handles are automatically closed if they are
+# reaped by reference counting.  You only need to call close
+# if you want to close the handle right away.
 g.close ()
