@@ -216,9 +216,6 @@ main (int argc, char *argv[])
       OPTION_d;
       break;
 
-    case 'h':
-      usage (EXIT_SUCCESS);
-
     case 'm':
       if (sscanf (optarg, "%u", &memsize) != 1) {
         fprintf (stderr, _("%s: could not parse memory size '%s'\n"),
@@ -339,7 +336,8 @@ main (int argc, char *argv[])
   /* Run the appliance.  This won't return until the user quits the
    * appliance.
    */
-  guestfs_set_error_handler (g, NULL, NULL);
+  if (!verbose)
+    guestfs_set_error_handler (g, NULL, NULL);
 
   /* We expect launch to fail, so ignore the return value, and don't
    * bother with explicit guestfs_shutdown either.
