@@ -22,7 +22,7 @@ open Resize_gettext.Gettext
 
 module G = Guestfs
 
-open Utils
+open Resize_utils
 
 (* Minimum surplus before we create an extra partition. *)
 let min_extra_partition = 10L *^ 1024L *^ 1024L
