@@ -23,7 +23,7 @@ open Sparsify_gettext.Gettext
 
 module G = Guestfs
 
-open Utils
+open Sparsify_utils
 
 let () = Random.self_init ()
 
@@ -169,14 +169,16 @@ let overlaydisk =
 
   (* Create it with the indisk as the backing file. *)
   let cmd =
-    let backing_file_option =
-      sprintf "backing_file=%s%s"
-        (replace_str indisk "," ",,")
-        (match format with
-        | None -> ""
-        | Some fmt -> sprintf ",backing_fmt=%s" fmt) in
+    let options =
+      let backing_file_option =
+        [sprintf "backing_file=%s" (replace_str indisk "," ",,")] in
+      let backing_fmt_option =
+        match format with
+        | None -> []
+        | Some fmt -> [sprintf "backing_fmt=%s" fmt] in
+      backing_file_option @ backing_fmt_option in
     sprintf "qemu-img create -f qcow2 -o %s %s > /dev/null"
-      (Filename.quote backing_file_option) (Filename.quote tmp) in
+      (Filename.quote (String.concat "," options)) (Filename.quote tmp) in
   if verbose then
     printf "%s\n%!" cmd;
   if Sys.command cmd <> 0 then
