@@ -28,10 +28,6 @@
 
 #include "hash.h"
 
-#ifndef O_CLOEXEC
-#define O_CLOEXEC 0
-#endif
-
 #ifndef SOCK_CLOEXEC
 #define SOCK_CLOEXEC 0
 #endif
@@ -74,7 +70,11 @@
   char var[strlen (ttos_tmpdir) + 32];                    \
   sprintf (var, "%s/libguestfsXXXXXX", ttos_tmpdir)       \
 
+#ifdef __APPLE__
+#define UNIX_PATH_MAX 104
+#else
 #define UNIX_PATH_MAX 108
+#endif
 
 #ifndef MAX
 #define MAX(a,b) ((a)>(b)?(a):(b))
@@ -226,6 +226,12 @@ struct guestfs_h
    */
   int user_cancel;
 
+  /* Used to generate unique numbers, eg for temp files.  To use this,
+   * '++g->unique'.  Note these are only unique per-handle, not
+   * globally unique.
+   */
+  int unique;
+
 #if HAVE_FUSE
   /* These fields are used by guestfs_mount_local. */
   const char *localmountpoint;
@@ -364,7 +370,7 @@ extern void guestfs_perrorf (guestfs_h *g, const char *fs, ...)
 extern void *guestfs_safe_realloc (guestfs_h *g, void *ptr, size_t nbytes);
 extern char *guestfs_safe_strdup (guestfs_h *g, const char *str);
 extern char *guestfs_safe_strndup (guestfs_h *g, const char *str, size_t n);
-extern void *guestfs_safe_memdup (guestfs_h *g, void *ptr, size_t size);
+extern void *guestfs_safe_memdup (guestfs_h *g, const void *ptr, size_t size);
 extern char *guestfs_safe_asprintf (guestfs_h *g, const char *fs, ...)
   __attribute__((format (printf,2,3)));
 extern void guestfs___warning (guestfs_h *g, const char *fs, ...)
@@ -374,6 +380,7 @@ extern void guestfs___debug (guestfs_h *g, const char *fs, ...)
 extern void guestfs___trace (guestfs_h *g, const char *fs, ...)
   __attribute__((format (printf,2,3)));
 extern const char *guestfs___persistent_tmpdir (void);
+extern int guestfs___lazy_make_tmpdir (guestfs_h *g);
 extern void guestfs___remove_tmpdir (const char *dir);
 extern void guestfs___print_timestamped_message (guestfs_h *g, const char *fs, ...);
 #if HAVE_FUSE
@@ -407,6 +414,7 @@ extern void guestfs___call_callbacks_message (guestfs_h *g, uint64_t event, cons
 extern void guestfs___call_callbacks_array (guestfs_h *g, uint64_t event, const uint64_t *array, size_t array_len);
 extern int guestfs___is_file_nocase (guestfs_h *g, const char *);
 extern int guestfs___is_dir_nocase (guestfs_h *g, const char *);
+extern void guestfs___launch_failed_error (guestfs_h *g);
 extern char *guestfs___download_to_tmp (guestfs_h *g, struct inspect_fs *fs, const char *filename, const char *basename, uint64_t max_size);
 extern char *guestfs___case_sensitive_path_silently (guestfs_h *g, const char *);
 extern struct inspect_fs *guestfs___search_for_root (guestfs_h *g, const char *root);
