@@ -30,37 +30,27 @@
 #include <string.h>
 #include <fcntl.h>
 #include <time.h>
+#include <assert.h>
+#include <errno.h>
 #include <sys/stat.h>
 #include <sys/select.h>
-#include <dirent.h>
-#include <assert.h>
+#include <sys/socket.h>
+#include <sys/types.h>
+#include <sys/un.h>
+#include <sys/wait.h>
 
 #include <rpc/types.h>
 #include <rpc/xdr.h>
 
-#ifdef HAVE_ERRNO_H
-#include <errno.h>
+#ifdef HAVE_LIBVIRT
+#include <libvirt/libvirt.h>
 #endif
 
-#ifdef HAVE_SYS_TYPES_H
-#include <sys/types.h>
+#ifdef HAVE_LIBXML2
+#include <libxml/parser.h>
+#include <libxml/xmlversion.h>
 #endif
 
-#ifdef HAVE_SYS_WAIT_H
-#include <sys/wait.h>
-#endif
-
-#ifdef HAVE_SYS_SOCKET_H
-#include <sys/socket.h>
-#endif
-
-#ifdef HAVE_SYS_UN_H
-#include <sys/un.h>
-#endif
-
-#include <arpa/inet.h>
-#include <netinet/in.h>
-
 #include "c-ctype.h"
 #include "glthread/lock.h"
 #include "hash.h"
@@ -79,6 +69,33 @@ gl_lock_define_initialized (static, handles_lock);
 static guestfs_h *handles = NULL;
 static int atexit_handler_set = 0;
 
+gl_lock_define_initialized (static, init_lock);
+
+/* No initialization is required by libguestfs, but libvirt and
+ * libxml2 require initialization if they might be called from
+ * multiple threads.  Hence this constructor function which is called
+ * when libguestfs is first loaded.
+ */
+static void init_libguestfs (void) __attribute__((constructor));
+
+static void
+init_libguestfs (void)
+{
+#if defined(HAVE_LIBVIRT) || defined(HAVE_LIBXML2)
+  gl_lock_lock (init_lock);
+#endif
+#ifdef HAVE_LIBVIRT
+  virInitialize ();
+#endif
+#ifdef HAVE_LIBXML2
+  xmlInitParser ();
+  LIBXML_TEST_VERSION;
+#endif
+#if defined(HAVE_LIBVIRT) || defined(HAVE_LIBXML2)
+  gl_lock_unlock (init_lock);
+#endif
+}
+
 guestfs_h *
 guestfs_create (void)
 {
@@ -215,7 +232,8 @@ guestfs_close (guestfs_h *g)
   guestfs___call_callbacks_void (g, GUESTFS_EVENT_CLOSE);
 
   /* Remove whole temporary directory. */
-  guestfs___remove_tmpdir (g->tmpdir);
+  if (g->tmpdir)
+    guestfs___remove_tmpdir (g->tmpdir);
 
   /* Mark the handle as dead and then free up all memory. */
   g->state = NO_HANDLE;
@@ -545,7 +563,7 @@ guestfs_safe_strndup (guestfs_h *g, const char *str, size_t n)
 }
 
 void *
-guestfs_safe_memdup (guestfs_h *g, void *ptr, size_t size)
+guestfs_safe_memdup (guestfs_h *g, const void *ptr, size_t size)
 {
   void *p = malloc (size);
   if (!p) g->abort_cb ();
@@ -812,9 +830,7 @@ guestfs__get_attach_method (guestfs_h *g)
     break;
 
   case ATTACH_METHOD_UNIX:
-    ret = safe_malloc (g, strlen (g->attach_method_arg) + 5 + 1);
-    strcpy (ret, "unix:");
-    strcat (ret, g->attach_method_arg);
+    ret = safe_asprintf (g, "unix:%s", g->attach_method_arg);
     break;
 
   default: /* keep GCC happy - this is not reached */
