@@ -27,7 +27,10 @@
 #include <string.h>
 #include <sys/stat.h>
 #include <errno.h>
+
+#ifdef HAVE_ENDIAN_H
 #include <endian.h>
+#endif
 
 #include <pcre.h>
 
@@ -35,8 +38,6 @@
 #include <hivex.h>
 #endif
 
-#include "c-ctype.h"
-#include "ignore-value.h"
 #include "xstrtol.h"
 
 #include "guestfs.h"
@@ -741,7 +742,9 @@ guestfs___download_to_tmp (guestfs_h *g, struct inspect_fs *fs,
   char devfd[32];
   int64_t size;
 
-  /* Make the basename unique by prefixing it with the fs number. */
+  /* Make the basename unique by prefixing it with the fs number.
+   * This also ensures there is one cache per filesystem.
+   */
   if (asprintf (&r, "%s/%td-%s", g->tmpdir, fs - g->fses, basename) == -1) {
     perrorf (g, "asprintf");
     return NULL;
