@@ -42,11 +42,11 @@
 //#define STRCASEEQ(a,b) (strcasecmp((a),(b)) == 0)
 //#define STRNEQ(a,b) (strcmp((a),(b)) != 0)
 //#define STRCASENEQ(a,b) (strcasecmp((a),(b)) != 0)
-#define STREQLEN(a,b,n) (strncmp((a),(b),(n)) == 0)
+//#define STREQLEN(a,b,n) (strncmp((a),(b),(n)) == 0)
 //#define STRCASEEQLEN(a,b,n) (strncasecmp((a),(b),(n)) == 0)
 //#define STRNEQLEN(a,b,n) (strncmp((a),(b),(n)) != 0)
 //#define STRCASENEQLEN(a,b,n) (strncasecmp((a),(b),(n)) != 0)
-//#define STRPREFIX(a,b) (strncmp((a),(b),strlen((b))) == 0)
+#define STRPREFIX(a,b) (strncmp((a),(b),strlen((b))) == 0)
 
 #ifndef P_tmpdir
 #define P_tmpdir "/tmp"
@@ -104,6 +104,17 @@ main (int argc, char *argv[])
   struct guestfs_version *vers;
   char *p;
 
+  /* Everyone ignores the documentation, so ... */
+  printf ("     ************************************************************\n"
+          "     *                    IMPORTANT NOTICE\n"
+          "     *\n"
+          "     * When reporting bugs, include the COMPLETE, UNEDITED\n"
+          "     * output below in your bug report.\n"
+          "     *\n"
+          "     ************************************************************\n"
+          );
+  sleep (3);
+
   /* Create the handle. */
   g = guestfs_create ();
   if (g == NULL) {
@@ -169,13 +180,24 @@ main (int argc, char *argv[])
   printf ("===== Test starts here =====\n");
 
   /* Print out any environment variables which may relate to this test. */
-  for (i = 0; environ[i] != NULL; ++i)
-    if (STREQLEN (environ[i], "LIBGUESTFS_", 11))
+  for (i = 0; environ[i] != NULL; ++i) {
+    if (STRPREFIX (environ[i], "LIBGUESTFS_"))
       printf ("%s\n", environ[i]);
-  for (i = 0; environ[i] != NULL; ++i)
-    if (STREQLEN (environ[i], "FEBOOTSTRAP_", 12))
+    if (STRPREFIX (environ[i], "FEBOOTSTRAP_"))
       printf ("%s\n", environ[i]);
-  printf ("TMPDIR=%s\n", getenv ("TMPDIR") ? : "(not set)");
+    if (STRPREFIX (environ[i], "LIBVIRT_"))
+      printf ("%s\n", environ[i]);
+    if (STRPREFIX (environ[i], "LIBVIRTD_"))
+      printf ("%s\n", environ[i]);
+    if (STRPREFIX (environ[i], "LD_"))
+      printf ("%s\n", environ[i]);
+  }
+  p = getenv ("TMPDIR");
+  if (p)
+    printf ("TMPDIR=%s\n", p);
+  p = getenv ("PATH");
+  if (p)
+    printf ("PATH=%s\n", p);
 
   /* Configure the handle. */
   if (guestfs_add_drive_opts (g, tmpf,
@@ -200,7 +222,7 @@ main (int argc, char *argv[])
   printf ("guestfs_get_direct: %d\n", guestfs_get_direct (g));
   printf ("guestfs_get_memsize: %d\n", guestfs_get_memsize (g));
   printf ("guestfs_get_network: %d\n", guestfs_get_network (g));
-  printf ("guestfs_get_path: %s\n", guestfs_get_path (g));
+  printf ("guestfs_get_path: %s\n", guestfs_get_path (g) ? : "(null)");
   printf ("guestfs_get_pgroup: %d\n", guestfs_get_pgroup (g));
   printf ("guestfs_get_qemu: %s\n", guestfs_get_qemu (g));
   printf ("guestfs_get_recovery_proc: %d\n", guestfs_get_recovery_proc (g));
