@@ -24,6 +24,9 @@ use warnings;
 use Sys::Guestfs;
 use Sys::Guestfs::Lib qw(feature_available);
 
+# Allow the test to be skipped since btrfs is often broken.
+exit 77 if $ENV{SKIP_TEST_BTRFS_SUBVOLUME_DEFAULT_PL};
+
 my $testimg = "test1.img";
 
 unlink $testimg;
@@ -39,7 +42,7 @@ $g->launch ();
 # If btrfs is not available, bail.
 unless (feature_available ($g, "btrfs")) {
     warn "$0: skipping test because btrfs is not available\n";
-    exit 0;
+    exit 77;
 }
 
 $g->part_disk ("/dev/sda", "mbr");
