@@ -23,12 +23,13 @@ set -e
 export LANG=C
 
 guestfish=../../fish/guestfish
+canonical="sed s,/dev/vd,/dev/sd,g"
 
-rm -f test1.img test.fstab test.output
+rm -f test1.qcow2 test.fstab test.output
 
 # Start with the regular (good) fedora image, modify /etc/fstab
 # and then inspect it.
-cp ../guests/fedora.img test1.img
+qemu-img create -F raw -b ../guests/fedora.img -f qcow2 test1.qcow2
 
 cat <<'EOF' > test.fstab
 /dev/VG/Root / ext2 default 0 0
@@ -36,26 +37,34 @@ cat <<'EOF' > test.fstab
 # Xen-style partition names.
 /dev/xvda1 /boot ext2 default 0 0
 
-# Non-existant device.
+# Non-existent device.
 /dev/sdb3 /var ext2 default 0 0
 
-# Non-existant mountpoint.
+# Non-existent mountpoint.
 /dev/VG/LV1 /nosuchfile ext2 default 0 0
+
+# /dev/disk/by-id path (RHBZ#627675).
+/dev/disk/by-id/ata-QEMU_HARDDISK_QM00001 /id ext2 default 0 0
+/dev/disk/by-id/ata-QEMU_HARDDISK_QM00001-part1 /id1 ext2 default 0 0
+/dev/disk/by-id/ata-QEMU_HARDDISK_QM00001-part3 /id3 ext2 default 0 0
 EOF
 
-$guestfish -a test1.img <<'EOF'
+$guestfish -a test1.qcow2 <<'EOF'
   run
   mount-options "" /dev/VG/Root /
   upload test.fstab /etc/fstab
 EOF
 
 # This will give a warning, but should not fail.
-$guestfish -a test1.img -i <<'EOF' | sort > test.output
+$guestfish -a test1.qcow2 -i <<'EOF' | sort | $canonical > test.output
   inspect-get-mountpoints /dev/VG/Root
 EOF
 
 if [ "$(cat test.output)" != "/: /dev/VG/Root
-/boot: /dev/vda1
+/boot: /dev/sda1
+/id1: /dev/sda1
+/id3: /dev/disk/by-id/ata-QEMU_HARDDISK_QM00001-part3
+/id: /dev/disk/by-id/ata-QEMU_HARDDISK_QM00001
 /nosuchfile: /dev/VG/LV1
 /var: /dev/sdb3" ]; then
     echo "$0: error #1: unexpected output from inspect-get-mountpoints command"
@@ -72,14 +81,14 @@ cat <<'EOF' > test.fstab
 /dev/xvdg1 /boot ext2 default 0 0
 EOF
 
-$guestfish -a test1.img <<'EOF'
+$guestfish -a test1.qcow2 <<'EOF'
   run
   mount-options "" /dev/VG/Root /
   upload test.fstab /etc/fstab
 EOF
 
-$guestfish <<'EOF' > test.output
-  add-drive-opts test1.img readonly:true name:xvdg
+$guestfish <<'EOF' | $canonical > test.output
+  add-drive-opts test1.qcow2 readonly:true name:xvdg
   run
   inspect-os
   inspect-get-mountpoints /dev/VG/Root
@@ -87,7 +96,7 @@ EOF
 
 if [ "$(cat test.output)" != "/dev/VG/Root
 /: /dev/VG/Root
-/boot: /dev/vda1" ]; then
+/boot: /dev/sda1" ]; then
     echo "$0: error #2: unexpected output from inspect-get-mountpoints command"
     cat test.output
     exit 1
@@ -103,14 +112,14 @@ cat <<'EOF' > test.fstab
 /dev/cciss/c1d3 /var ext2 default 0 0
 EOF
 
-$guestfish -a test1.img <<'EOF'
+$guestfish -a test1.qcow2 <<'EOF'
   run
   mount-options "" /dev/VG/Root /
   upload test.fstab /etc/fstab
 EOF
 
-$guestfish <<'EOF' > test.output
-  add-drive-opts test1.img readonly:true name:cciss/c1d3
+$guestfish <<'EOF' | $canonical > test.output
+  add-drive-opts test1.qcow2 readonly:true name:cciss/c1d3
   run
   inspect-os
   inspect-get-mountpoints /dev/VG/Root
@@ -118,13 +127,13 @@ EOF
 
 if [ "$(cat test.output)" != "/dev/VG/Root
 /: /dev/VG/Root
-/boot: /dev/vda1
-/var: /dev/vda" ]; then
+/boot: /dev/sda1
+/var: /dev/sda" ]; then
     echo "$0: error #3: unexpected output from inspect-get-mountpoints command"
     cat test.output
     exit 1
 fi
 
 rm test.fstab
-rm test1.img
+rm test1.qcow2
 rm test.output
